--[[

Name: MusicStrem
Revision: $Revision: 25931 $
Date: $Date: 2007-01-23 18:43:23 -0500 (Tue, 23 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: Play Streaming Music in World of Warcraft.
Dependencies: Ace2

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 25931 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("MusicStream")

L:RegisterTranslations("enUS", function() return {
    ["Music Stream"] = true,
	["Plays Streaming Music"] = true,
	["Shows the Options Dropdown"] = true,
	["Stop"] = true,
	["Stop Music"] = true,
	["Prev"] = true,
	["Previous Channel"] = true,
	["Play"] = true,
	["Play Channel"] = true,
	["Next"] = true,
	["Next Channel"] = true,
	["Settings"] = true,
	["Change MusicStream Settings"] = true,
	["General Settings"] = true,
	["Channels"] = true,
	["Change Channel to Play"] = true,
	["Channel Settings"] = true,
    ["Disabled Modules"] = true,
	["Options"] = true,
	["Change Settings"] = true,
	["Advanced Settings"] = true,
	["Options you may not want to mess with"] = true,
	["Reset DB to Defaults"] = true,
	["Reset the Database back to Defaults"] = true,
	["Debugging"] = true,
	["Toggle Debugging for this Addon"] = true,
} end)

--- ========================================================= ---
--- Register DB for Music Stream
--- ========================================================= ---
MusicStream = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "AceDebug-2.0", "AceEvent-2.0", "AceModuleCore-2.0")
MusicStream.dewdrop = AceLibrary("Dewdrop-2.0")

MusicStream:RegisterDB("MusicStreamDB")
MusicStream:SetModuleMixins("AceEvent-2.0", "AceDebug-2.0")

MusicStream.defaultDB = {
}

local bluecolor = "|cFF0099CC"
local lbluecolor = "|cFF77BBFF"
local redcolor = "|cFFFF5522"
local greycolor = "|c77AAAAAA"

MusicStream.Options = {type = "group", handler = MusicStream, args = {
		header = {
			type = "header",
			name = bluecolor..L["Music Stream"].."  |c88888888"..Revision,
			icon = "Interface\\Addons\\MusicStream\\icon.tga",
			iconHeight = 28,
			iconWidth = 28,
			order = 1
		}, 
		stop = {
			name = L["Stop"],
			desc = L["Stop Music"],
			order = 100,
			type = "execute",
			func = function() MusicStream:Stop(); end,
		},
		prev = {
			name = L["Prev"],
			desc = L["Previous Channel"],
			order = 101,
			type = "execute",
			func = function() MusicStream:Prev(); end,
		},
		play = {
			name = L["Play"],
			desc = L["Play Channel"],
			order = 102,
			type = "execute",
			func = function() MusicStream:Play(); end,
		},
		next = {
			name = L["Next"],
			desc = L["Next Channel"],
			order = 103,
			type = "execute",
			func = function() MusicStream:Next(); end,
		},

		
		optionsheaderblank = {
			type = 'header',
			order = 199,
		},
		optionsheader = {
			type = "header",
			name = lbluecolor..L["Options"],
			icon = "Interface\\GossipFrame\\TrainerGossipIcon",
			order = 200
		}, 
		
		settingsheaderblank = {
			type = 'header',
			order = 299,
		},
		settingsheader = {
			type = "header",
			name = lbluecolor..L["Settings"],
			icon = "Interface\\GossipFrame\\BinderGossipIcon",
			order = 300
		}, 
		settings = {
			name = L["Change Settings"],
			desc = L["Change MusicStream Settings"],
			order = 301,
			type = 'group',
			args = {
				generalheader = {
					type = "header",
					name = lbluecolor..L["General Settings"],
					icon = "Interface\\GossipFrame\\BinderGossipIcon",
					order = 100
				}, 
				advancedheaderblank = {
					type = 'header',
					order = 999,
				},
				advancedheader = {
					type = "header",
					name = lbluecolor..L["Advanced Settings"],
					icon = "Interface\\GossipFrame\\BinderGossipIcon",
					order = 1000
				},
				advancedsettings = {
					name = greycolor..L["Advanced Settings"],
					desc = greycolor..L["Options you may not want to mess with"],
					order = 1001,
					type = 'group',
					args = {
						header = {
							type = "header",
							name = lbluecolor..L["Advanced Settings"],
							icon = "Interface\\GossipFrame\\BinderGossipIcon",
							order = 1
						},
						blank = {
							type = 'header',
							order = 2,
						},
						reset = {
							name = redcolor..L["Reset DB to Defaults"],
							desc = greycolor..L["Reset the Database back to Defaults"],
							order = 200,
							type = "execute",
							confirm = true,
							func = function() MusicStream:ResetDB(); end,
						},
					},
				},
			},
		},
		
		options = {
			name = L["Options"],
			desc = L["Shows the Options Dropdown"],
			order = 300,
			type = "execute",
			func = function() MusicStream:OpenMenu(UIParent) end,
			guiHidden = true
		},
    }
}

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStream:OnInitialize()
	MusicStream:RegisterDefaults("profile", {
		debug = false,
	})
	
	self:RegisterEvent("Ace2_AddonDisabled")
	self:RegisterEvent("Ace2_AddonEnabled")
	self:RegisterEvent("AceEvent_FullyInitialized")
end

--- ========================================================= ---
--- On Full Initialize
--- ========================================================= ---

function MusicStream:AceEvent_FullyInitialized()
	self:SetDebugging(self.db.profile.debug)
end

--- ========================================================= ---
--- On Addon Disabled
--- ========================================================= ---

function MusicStream:Ace2_AddonDisabled(mod)
	self:Debug("Ace2_AddonDisabled - "..mod.name)
end

--- ========================================================= ---
--- On Addon Enabled
--- ========================================================= ---

function MusicStream:Ace2_AddonEnabled(mod)
	self:Debug("Ace2_AddonEnabled - "..mod.name)
end

--- ========================================================= ---
--- On Debug Enable
--- ========================================================= ---

function MusicStream:OnDebugEnable()
	self.db.profile.debug = true
	self:Debug("Debug - ON")
end	

--- ========================================================= ---
--- On Debug Enable
--- ========================================================= ---

function MusicStream:OnDebugDisable()
	self.db.profile.debug = false
	self:Debug("Debug - OFF")
end

--- ========================================================= ---
--- Register Chat Command
--- ========================================================= ---

MusicStream:RegisterChatCommand({"/musicstream"}, MusicStream.Options)

--- ========================================================= ---
--- Options Dropdown
--- ========================================================= ---

function MusicStream:OpenMenu(frame)
	self.dewdrop:Open(frame,
		'children', function(level, value)
				self.dewdrop:FeedAceOptionsTable(self.Options)
			end,
		'cursorX', true,
		'cursorY', true
	)
end

--- ========================================================= ---
--- Get Fu Options
--- ========================================================= ---

function MusicStream:GetFuOptions()
	MusicStream.Options.args.settings.args = {
		name = L["FuBar Options"],
        desc = L["A module to change FuBar Options."],
        type = "group",
        args = {
			spacing = {
				name = L["Button Spacing"],
				desc = L["Set Button Spacing"],
				type = 'range',
				min  = 0,
				max  = 10,
				step = 0.5,
				set  = function(size) MusicStreamFu:SetButtonSpacing(size) end,
				get  = function() return MusicStreamFu:GetButtonSpacing() end,
			},
			visibility = {
				type = 'group',
				name = L["Button Visibility"],
				desc = L["Toggle Button Visibility"],
				args = {
				}
			},
		},
	}
end

--- ========================================================= ---
--- ResetDB
--- ========================================================= ---

function MusicStream:ResetDB()
	for name, module in self:IterateModules() do
		if type(module.ResetDB) == "function" then
			module:ResetDB();
			self:Debug(name.." successfully reset.")
		end
	end
end

--- ========================================================= ---
--- Play
--- ========================================================= ---

function MusicStream:Play()
	self:TriggerEvent("Music_Control", "Play")
end

--- ========================================================= ---
--- Stop
--- ========================================================= ---

function MusicStream:Stop()
	self:TriggerEvent("Music_Control", "Stop")
end

--- ========================================================= ---
--- Next
--- ========================================================= ---

function MusicStream:Next()
	self:TriggerEvent("Music_Control", "Next")
end

--- ========================================================= ---
--- Prev
--- ========================================================= ---

function MusicStream:Prev()
	self:TriggerEvent("Music_Control", "Prev")
end