--[[

Name: MusicStrem FuBar Settings
Revision: $Revision: 23844 $
Date: $Date: 2007-01-07 03:01:22 -0500 (Sun, 07 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A Module to change various FuBar Settings in MusicStream.
Dependencies: Ace2, FuBar, MusicStream

]]--

if not IsAddOnLoaded("FuBar") then return end

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 23844 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("FuBarSettings")

L:RegisterTranslations("enUS", function() return {
	["FuBar Settings"] = true,
	
	["Button Spacing"] = true,
	["Set Button Spacing"] = true,
	["Button Visibility"] = true,
	["Toggle Button Visibility"] = true,
} end)

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamFuBarSettings = MusicStream:NewModule("FuBarSettings")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamFuBarSettings:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("FuBarSettings")

	MusicStreamFuBarSettings.defaultDB = {
    }
	
	MusicStream:RegisterDefaults("FuBarSettings", "profile", opts or MusicStreamFuBarSettings.defaultDB or {})
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
	MusicStream.Options.args.settings.args.FuBarSettingsBlank = {
       	type = "header",
		order = 399,
	}
	
	MusicStream.Options.args.settings.args.FuBarSettings = {
		name = lbluecolor..L["FuBar Settings"],
		icon = "Interface\\GossipFrame\\BinderGossipIcon",
       	type = "header",
		order = 400,
	}
	
	MusicStream.Options.args.settings.args.FuBarSettingsSpacing = {
		name = L["Button Spacing"],
		desc = L["Set Button Spacing"],
		order = 401,
		type = 'range',
		min  = 0,
		max  = 10,
		step = 0.5,
		set  = function(size) MusicStreamFu:SetButtonSpacing(size) end,
		get  = function() return MusicStreamFu:GetButtonSpacing() end,
	}
	
	MusicStream.Options.args.settings.args.FuBarSettingsVisibility = {
		name = L["Button Visibility"],
		desc = L["Toggle Button Visibility"],
       	type = "group",
		order = 402,
		args = {
		}
	}
	
	MusicStreamFu:GetButtons()
	
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamFuBarSettings:ResetDB()
	copyTable(self.db.profile, MusicStreamFuBarSettings.defaultDB)
end