--[[

Name: MusicStrem Player Settings
Revision: $Revision: 23844 $
Date: $Date: 2007-01-07 03:01:22 -0500 (Sun, 07 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to control various Player settings.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 23844 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("PlayerSettings")

L:RegisterTranslations("enUS", function() return {
	["Player Settings"] = true,
	["Apperance"] = true,
	["Change the Apperance of the Player"] = true,
	["Backdrop Color"] = true,
	["Change the Player's Backdrop Color"] = true,
	["Border Color"] = true,
	["Change the Player's Border Color"] = true,
	["Channel Color"] = true,
	["Change the Player's Channel Color"] = true,
	["Player Scale"] = true,
	["Set the Player's Scale"] = true,
	["Player Lock"] = true,
	["Toggle the Player's Lock Status"] = true,
	["Show ID3 Tags"] = true,
	["Toggle showing the Scrolling ID3 Tags on the Player"] = true,
	["Show Time Playing"] = true,
	["Toggle showing how long the song has been playing on the Player"] = true,
	["Toggle Player"] = true,
	["Toggle the Player's Frame"] = true,
} end)

--- ========================================================= ---
--- Add Music Library
--- ========================================================= ---
local Music = AceLibrary("Music-2.0")

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamPlayerSettings = MusicStream:NewModule("PlayerSettings")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamPlayerSettings:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("PlayerSettings")
	
	MusicStreamPlayerSettings.defaultDB = {
		playerscale = 1,
		lock = false,
		show = true,
		showidtags = true,
		showtimeplaying = true,
		
		backdropcolor = {
            r = 0.10,
            g = 0.10,
            b = 0.10,
            a = 1.00,
        },
		bordercolor = {
            r = 0.90,
            g = 0.90,
            b = 0.90,
            a = 1.00,
        },
		channelcolor = {
            r = 0.90,
            g = 0.90,
            b = 0.90,
            a = 1.00,
        },
    }
	
	MusicStream:RegisterDefaults("PlayerSettings", "profile", opts or MusicStreamPlayerSettings.defaultDB or {})
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
	MusicStream.Options.args.settings.args.PlayerSettingsBlank = {
       	type = "header",
		order = 299,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettings = {
		name = lbluecolor..L["Player Settings"],
		icon = "Interface\\GossipFrame\\BinderGossipIcon",
       	type = "header",
		order = 300,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettingsApperance = {
		name = L["Apperance"],
		desc = L["Change the Apperance of the Player"],
       	type = "group",
		order = 301,
		args = {
			header = {
				type = "header",
				name = bluecolor..L["Player Settings"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			backdropcolor = {
				name = L["Backdrop Color"],
				desc = L["Change the Player's Backdrop Color"],
				order = 100,
    			type = 'color',
    			get = function() return 
					self.db.profile.backdropcolor.r,
                	self.db.profile.backdropcolor.g,
                	self.db.profile.backdropcolor.b,
					self.db.profile.backdropcolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.backdropcolor.r,
                	self.db.profile.backdropcolor.g,
                	self.db.profile.backdropcolor.b,
					self.db.profile.backdropcolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetBackdropColor();
    			end,
    			hasAlpha = true
			},
			bordercolor = {
				name = L["Border Color"],
				desc = L["Change the Player's Border Color"],
				order = 200,
    			type = 'color',
    			get = function() return 
					self.db.profile.bordercolor.r,
                	self.db.profile.bordercolor.g,
                	self.db.profile.bordercolor.b,
					self.db.profile.bordercolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.bordercolor.r,
                	self.db.profile.bordercolor.g,
                	self.db.profile.bordercolor.b,
					self.db.profile.bordercolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetBorderColor();
    			end,
    			hasAlpha = true
			},
			channelcolor = {
				name = L["Channel Color"],
				desc = L["Change the Player's Channel Color"],
				order = 300,
    			type = 'color',
    			get = function() return 
					self.db.profile.channelcolor.r,
                	self.db.profile.channelcolor.g,
                	self.db.profile.channelcolor.b,
					self.db.profile.channelcolor.a
    			end,
    			set = function(r, g, b, a)
                	self.db.profile.channelcolor.r,
                	self.db.profile.channelcolor.g,
                	self.db.profile.channelcolor.b,
					self.db.profile.channelcolor.a
					= r, g, b, a;
					MusicStreamPlayerSettings:SetChannelColor();
    			end,
    			hasAlpha = true
			},
		}
	}
		
	MusicStream.Options.args.settings.args.PlayerSettingsScale = {
		name = L["Player Scale"],
		desc = L["Set the Player's Scale"],
		order = 302,
		type = 'range',
		min  = 0.1,
		max  = 1.0,
		step = 0.05,
		set  = function(scale) self.db.profile.playerscale = scale;  MusicStreamPlayerSettings:SetScale(); end,
		get  = function() return self.db.profile.playerscale end,
	}
	
	MusicStream.Options.args.settings.args.PlayerSettingsLock = {
        name = L["Player Lock"],
        desc = L["Toggle the Player's Lock Status"],
		order = 303,
        type = "toggle",
        get = function() return self.db.profile.lock end,
        set = function() self.db.profile.lock = not self.db.profile.lock end
	}
	MusicStream.Options.args.settings.args.PlayerSettingsIDTags = {
        name = L["Show ID3 Tags"],
        desc = L["Toggle showing the Scrolling ID3 Tags on the Player"],
		order = 303,
        type = "toggle",
        get = function() return self.db.profile.showidtags end,
        set = function() self.db.profile.showidtags = not self.db.profile.showidtags end
	}
	MusicStream.Options.args.settings.args.PlayerSettingsTimePlaying = {
        name = L["Show Time Playing"],
        desc = L["Toggle showing how long the song has been playing on the Player"],
		order = 303,
        type = "toggle",
        get = function() return self.db.profile.showtimeplaying end,
        set = function() self.db.profile.showtimeplaying = not self.db.profile.showtimeplaying end
	}
	
	MusicStream.Options.args.PlayerToggle = {
        name = L["Toggle Player"],
        desc = L["Toggle the Player's Frame"],
		order = 1000,
        type = "execute",
		func = function() self:TogglePlayer() end,
	}

end

--- ========================================================= ---
--- On Enable
--- ========================================================= ---

function MusicStreamPlayerSettings:OnEnable()
	MusicStreamPlayer:SetBackdropColor(self.db.profile.backdropcolor.r, self.db.profile.backdropcolor.g, self.db.profile.backdropcolor.b, self.db.profile.backdropcolor.a);
	MusicStreamPlayer:SetBackdropBorderColor(self.db.profile.bordercolor.r, self.db.profile.bordercolor.g, self.db.profile.bordercolor.b, self.db.profile.bordercolor.a);
	MSNowPlaying:SetTextColor(self.db.profile.channelcolor.r, self.db.profile.channelcolor.g, self.db.profile.channelcolor.b, self.db.profile.channelcolor.a);
	MusicStreamPlayer:SetScale(self.db.profile.playerscale);
	
	if not self.db.profile.show then
		MusicStreamPlayer:Hide();
	else
		MusicStreamPlayer:Show();
	end
	
	if not(Music:TracksLoaded()) then MSNowPlaying:SetText("No Tracks Loaded"); end
	
	self:RegisterEvent("Music_Control")
	self:RegisterEvent("Music_Changed")
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamPlayerSettings:ResetDB()
	copyTable(self.db.profile, MusicStreamPlayerSettings.defaultDB)
end

--- ========================================================= ---
--- Music Control
--- ========================================================= ---

function MusicStreamPlayerSettings:Music_Control(command)
	if command == "Stop" then
		self:CancelScheduledEvent("ShowIDTags")
		self:CancelScheduledEvent("ShowTimePlaying")
		
		if not(Music:TracksLoaded()) then MSNowPlaying:SetText("No Tracks Loaded"); else MSNowPlaying:SetText("Standby"); end
		
		MSTimePlaying:SetText("");
		MSTimeLengthPlaying:SetText("");
	end
end

function MusicStreamPlayerSettings:Music_Changed()
	if not self.db.profile.showidtags then
		MSNowPlaying:SetText(Music:CurrentTitle());
		self:CancelScheduledEvent("ShowIDTags")
	else
		MSNowPlaying:SetText(Music:CurrentTitle());
		self:ScheduleRepeatingEvent("ShowIDTags", self.ShowIDTags, 3, self)
	end
	
	if not self.db.profile.showtimeplaying then
		MusicStreamPlayerSettings:ShowTimeLengthPlaying()
		MSTimePlaying:SetText("");
		self:CancelScheduledEvent("ShowTimePlaying")
	else
		MusicStreamPlayerSettings:ShowTimeLengthPlaying()
		TimePlaying = 0;
		MSTimePlaying:SetText("00:00");
		self:ScheduleRepeatingEvent("ShowTimePlaying", self.ShowTimePlaying, 1, self)
	end
end

--- ========================================================= ---
--- Show ID3 Tags
--- ========================================================= ---

function MusicStreamPlayerSettings:ShowIDTags()
	if not idtag then
		idtag = 1;
	end
	
	if idtag == 1 then
		MSNowPlaying:SetText(Music:CurrentTitle());
		idtag = 2;
	else 
		if idtag == 2 then
			MSNowPlaying:SetText(Music:CurrentArtist());
			idtag = 3;
		else 
			if idtag == 3 then
				MSNowPlaying:SetText(Music:CurrentAlbum());
				idtag = 1;
			end
		end
	end
end

--- ========================================================= ---
--- Show Time Length Playing
--- ========================================================= ---

function MusicStreamPlayerSettings:ShowTimeLengthPlaying()
	Minutes = math.floor(Music:CurrentLength() / 60);
	Seconds = Music:CurrentLength() - (Minutes * 60)
	
	if Minutes < 10 then
		Minutes = "0"..Minutes;
	end
	
	if Seconds < 10 then
		Seconds = "0"..Seconds;
	end
	
	TotalTime = Minutes..":"..Seconds;
	MSTimeLengthPlaying:SetText(TotalTime);
end

--- ========================================================= ---
--- Show Time Playing
--- ========================================================= ---

function MusicStreamPlayerSettings:ShowTimePlaying()
	TimePlaying = TimePlaying + 1;

	Minutes = math.floor(TimePlaying / 60);
	Seconds = TimePlaying - (Minutes * 60)
	
	if Minutes < 10 then
		Minutes = "0"..Minutes;
	end
	
	if Seconds < 10 then
		Seconds = "0"..Seconds;
	end
	
	TotalTime = Minutes..":"..Seconds;
	MSTimePlaying:SetText(TotalTime);
end

--- ========================================================= ---
--- Set Player BackdropColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetBackdropColor()
	MusicStreamPlayer:SetBackdropColor(self.db.profile.backdropcolor.r, self.db.profile.backdropcolor.g, self.db.profile.backdropcolor.b, self.db.profile.backdropcolor.a);
end

--- ========================================================= ---
--- Set Player BorderColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetBorderColor()
	MusicStreamPlayer:SetBackdropBorderColor(self.db.profile.bordercolor.r, self.db.profile.bordercolor.g, self.db.profile.bordercolor.b, self.db.profile.bordercolor.a);
end

--- ========================================================= ---
--- Set Player ChannelColor
--- ========================================================= ---

function MusicStreamPlayerSettings:SetChannelColor()
	MSNowPlaying:SetTextColor(self.db.profile.channelcolor.r, self.db.profile.channelcolor.g, self.db.profile.channelcolor.b, self.db.profile.channelcolor.a);
end

--- ========================================================= ---
--- Set Player Scale
--- ========================================================= ---

function MusicStreamPlayerSettings:SetScale()
	MusicStreamPlayer:SetScale(self.db.profile.playerscale);
end

--- ========================================================= ---
--- Check Player Lock Status
--- ========================================================= ---

function MusicStreamPlayerSettings:CheckLock()
	if not self.db.profile.lock then
		if(arg1 == "LeftButton") then
			MusicStreamPlayer:StartMoving();
		end
	end
end

--- ========================================================= ---
--- Toggle Player
--- ========================================================= ---

function MusicStreamPlayerSettings:TogglePlayer()
	if (MusicStreamPlayer:IsVisible()) then
		MusicStreamPlayer:Hide();
	else
		MusicStreamPlayer:Show();
	end
	self.db.profile.show = not self.db.profile.show
end

--- ========================================================= ---
--- MusicStream Player Music Mute Check
--- ========================================================= ---

function MusicStreamPlayerSettings:GetEnableMusic()
	local Volume = getglobal(this:GetName());
	
---Added in the corrected naming conventions	

	if GetCVar("Sound_EnableMusic") == "1" and "0" then
		Volume:SetNormalTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute.tga")
		Volume:SetPushedTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute_Pushed.tga")
		Volume:SetHighlightTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_UnMute_Pushed.tga", "BLEND")
	else
		Volume:SetNormalTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute.tga")
		Volume:SetPushedTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute_Pushed.tga")
		Volume:SetHighlightTexture("Interface\\AddOns\\MusicStream\\images\\PlayerVolume_Mute_Pushed.tga", "BLEND")
	end
end

--- ========================================================= ---
--- MusicStream Player Music Toggle
--- ========================================================= ---

function MusicStreamPlayerSettings:ToggleEnableMusic()

---Added in the corrected naming conventions

	SetCVar("Sound_EnableMusic", GetCVar("Sound_EnableMusic") == "1" and 0 or 1)
end