﻿--[[

Name: MusicStrem Track Alert
Revision: $Revision: 23844 $
Date: $Date: 2007-01-07 03:01:22 -0500 (Sun, 07 Jan 2007) $
Author(s): benumbed (someone@somewhere.com)
Website: http://www.wowace.com/wiki/MusicStream
Documentation: http://www.wowace.com/wiki/MusicStream
SVN: http://svn.wowace.com/root/trunk/MusicStream
Description: A module to alert you when you play music through messages.
Dependencies: Ace2, MusicStream

]]--

--- ========================================================= ---
--- Revision
--- ========================================================= ---

local Revision = tonumber(string.sub("$Revision: 23844 $", 12, -3))
if not Revision then
	Revision = "2.0"
end

--- ========================================================= ---
--- Add Locale
--- ========================================================= ---
local L = AceLibrary("AceLocale-2.2"):new("TrackAlert")

L:RegisterTranslations("enUS", function() return {
    ["Track Alert"] = true,
    ["Alert Music being played through messages"] = true,
	
    ["Toggle"] = true,
    ["Toggle the Module On and Off"] = true,
	
	["Show"] = true,
    ["Toggle showing where to display the messages"] = true,
	
	["Show UIMessageFrame"] = true,
    ["Toggles showing message in UI Message Fram."] = true,
	["Show ChatFrame"] = true,
    ["Toggles showing message in Chat Frame"] = true,
} end)

--- ========================================================= ---
--- Add Music Library
--- ========================================================= ---
local Music = AceLibrary("Music-2.0")

--- ========================================================= ---
--- Register New Module
--- ========================================================= ---

MusicStreamTrackAlert = MusicStream:NewModule("TrackAlert")

--- ========================================================= ---
--- On Initialize
--- ========================================================= ---

function MusicStreamTrackAlert:OnInitialize()
    self.db = MusicStream:AcquireDBNamespace("TrackAlert")

    MusicStreamTrackAlert.defaultDB = {
        on = true,
		show = {true, false},
    }
	
	MusicStream:RegisterDefaults("TrackAlert", "profile", opts or MusicStreamTrackAlert.defaultDB or {})
	
    MusicStream:ToggleModuleActive("TrackAlert", self.db.profile.on)
    
	local bluecolor = "|cFF0099CC"
	local lbluecolor = "|cFF77BBFF"
	
    MusicStream.Options.args.settings.args.TrackAlert = {
        name = L["Track Alert"],
        desc = L["Alert Music being played through messages"],
		order = 102,
        type = "group",
        args = {
			header = {
				type = "header",
				name = bluecolor..L["Track Alert"].."  |c88888888"..Revision,
				icon = "Interface\\Addons\\MusicStream\\icon.tga",
				iconHeight = 14,
				iconWidth = 14,
				order = 1
            },
			blank = {
       			type = "header",
				order = 2,
			},
			show = {
                name = L["Show"],
                desc = L["Toggle showing where to display the messages"],
				order = 100,
                type = "group",
                args = {
                    chatframe = {
                        name = string.format(L["Show ChatFrame"], 2),
                        desc = string.format(L["Toggles showing message in Chat Frame"], 2),
						order = 100,
                        type = "toggle",
                        get = function() return self.db.profile.show[2] end,
                        set = function(v) self.db.profile.show[2] = v end
                    },
					uimessageframe = {
                        name = string.format(L["Show UIMessageFrame"], 1),
                        desc = string.format(L["Toggle the Module On and Off"], 1),
						order = 105,
                        type = "toggle",
                        get = function() return self.db.profile.show[1] end,
                        set = function(v) self.db.profile.show[1] = v end
                    },
                },
            },
			blank = {
				type = 'header',
				order = 195,
			},
             toggle = {
                name = L["Toggle"],
                desc = L["Toggle the Module On and Off"],
                type = "toggle",
                order = 200,
                get = function() return self.db.profile.on end,
                set = function() self.db.profile.on = MusicStream:ToggleModuleActive("TrackAlert") end
            }
        }
    }
end

--- ========================================================= ---
--- On Enable
--- ========================================================= ---

function MusicStreamTrackAlert:OnEnable()
    self:RegisterEvent("Music_Control")
	self:RegisterEvent("Music_Changed")
end

--- ========================================================= ---
--- Reset DB
--- ========================================================= ---

local function copyTable(to, from)
	setmetatable(to, nil)
	for k,v in pairs(from) do
		if type(k) == "table" then
			k = copyTable({}, k)
		end
		if type(v) == "table" then
			v = copyTable({}, v)
		end
		to[k] = v
	end
	setmetatable(to, from)
	return to
end

function MusicStreamTrackAlert:ResetDB()
	copyTable(self.db.profile, MusicStreamTrackAlert.defaultDB)
end

--- ========================================================= ---
--- Alert
--- ========================================================= ---

function MusicStreamTrackAlert:TrackAlert(txt)
	if (self.db.profile.on == true) then
		if (self.db.profile.show[1] == true) then
			if (IsAddOnLoaded("SCT")) then
				SCT:DisplayCustomEvent(txt,{r=1,g=1,b=1}, iscrit);
			else
				UIErrorsFrame:AddMessage(txt,1, 1, 1, 1,10);
			end
		end
		if (self.db.profile.show[2] == true) then
			DEFAULT_CHAT_FRAME:AddMessage(txt);
		end
	end
end

--- ========================================================= ---
--- Alert to Selected Frame(s)
--- ========================================================= ---

function MusicStreamTrackAlert:Music_Control(command)
	if command == "Stop" then
		MusicStreamTrackAlert:TrackAlert("Music Stopped");
	end
end

function MusicStreamTrackAlert:Music_Changed()
	MusicStreamTrackAlert:TrackAlert("Title: "..Music:CurrentTitle());
end